from setuptools import setup, find_packages

setup(
    name="quadexpo",
    version="1.0",
    author="Sourceduty",
    author_email="sourceduty@gmail.com",
    description="A mathematical library implementing the Quadexpo function",
    long_description=open("README.md").read(),
    long_description_content_type="text/markdown",
    url="https://sourceduty.com",
    packages=find_packages(),
    install_requires=[
        "numpy",
        "scipy",
        "matplotlib"
    ],
    classifiers=[
        "Programming Language :: Python :: 3",
        "License :: OSI Approved :: MIT License",
        "Operating System :: OS Independent",
    ],
    python_requires='>=3.6',
)
